# ABP Tools

![ABP Logo](https://mazegroup.org//wiki/images/e/ed/ABP_logo.png)

ABP (Additional Binary Patterns) is a string encryption algorithm, designed on March 31, 2025. It is based on the use of a table of patterns to transform a text in a reversible way.
_From the [MazeGroup Wiki page](https://mazegroup.org/wiki/index.php/ABP) (in french)._
